flushAndromeda: Flush changes to disk

View source: R/Operations.R

flushAndromedaR Documentation

Flush changes to disk

Description

Flush all changes to disk. This only affects the data in the Andromeda temp folder.

This function is for advanced users, who wish to share the same underlying object with other processes, which is very dangerous if you don't know what you're doing.

Usage

flushAndromeda(andromeda, evictCache = TRUE)

Arguments

andromeda

An Andromeda object.

evictCache

If TRUE, will also evict the cache to free up memory.

Value

This function does not return anything, but is executed for its side-effect.

Examples

andr <- andromeda()
andr$cars <- cars

flushAndromeda(andr)
# The database in andromeda temp is now fully up-to-date.

close(andr)


Andromeda documentation built on June 11, 2026, 9:07 a.m.