| flushAndromeda | R Documentation |
Flush all changes to disk. This only affects the data in the Andromeda temp folder.
This function is for advanced users, who wish to share the same underlying object with other processes, which is very dangerous if you don't know what you're doing.
flushAndromeda(andromeda, evictCache = TRUE)
andromeda |
An |
evictCache |
If TRUE, will also evict the cache to free up memory. |
This function does not return anything, but is executed for its side-effect.
andr <- andromeda()
andr$cars <- cars
flushAndromeda(andr)
# The database in andromeda temp is now fully up-to-date.
close(andr)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.